# STARS - Spatio-Temporal Analytics with Rapid Solutions

libkdv-stars is the leading solution for ....

<img width="849" alt="03e58de5950a5d503b73952e8a3bbd1" src="https://user-images.githubusercontent.com/96175669/146165826-eef5f116-3e37-4bec-91dc-899af61fed18.png">

# Core source codes
https://github.com/edisonchen/xxxx

# Project members
[Dr. Edison ...](https:///xxxx), Hong Kong Baptist University<br />
[Prof. Ryan L.H. U](https://www.fst.um.edu.mo/personal/ryanlhu/), Universiy of Macau
.... 

# Publications
